@@ -224,7 +224,7 @@ class Vyos(Main):  # Vyos/EdgeOS specific commands
     def get_bgp_summary(self):
         raw = (self.SSHConnection.send_command("show ip bgp summary"))
 
-        with open('vyosbgp.template.py') as template:
+        with open('vyosbgp.template') as template:
             fsm = textfsm.TextFSM(template)
             result = fsm.ParseText(raw)
         
